@@ -1,6 +1,6 @@
-#' Print the agent to the terminal
+#' Print the agent information to the console
 #'
-#' This function will allow the agent to provide a summary report.
+#' This function will allow the agent to provide a short message in the console.
 #' 
 #' @param x An agent object of class `ptblank_agent`.
 #' 
@@ -8,45 +8,28 @@
 #' @export
 print.ptblank_agent <- function(x, ...) {
   
+  # nocov start 
+  
   args <- list(...)
   args <- NULL
   
   # Get the console width
   console_width <- getOption("width")
-  
-  # Get the tables focussed on
-  tables_of_focus <-
-    x$validation_set %>%
-    dplyr::mutate(tbl_name_type = paste0(tbl_name, "/", db_type)) %>%
-    dplyr::select(tbl_name_type) %>%
-    dplyr::group_by(tbl_name_type) %>%
-    dplyr::summarize(n = dplyr::n()) %>%
-    dplyr::ungroup() %>%
-    dplyr::transmute(tbl_name_type_n = paste0(tbl_name_type, " (", n, ")")) %>%
-    dplyr::pull(tbl_name_type_n)
-  
-  if (length(tables_of_focus) == 0 & 
-      length(x$focal_tbl_name) != 0) {
-    tables_of_focus <- paste0(x$focal_tbl_name, "/", x$focal_db_type, " (1)") 
-  }
-  
+
   # Generate the complete statement for printing
   if (is_agent_empty(x)) {
     
-    print_stmt <- paste0("pointblank agent // <", x$validation_name, ">")
+    print_stmt <- paste0("pointblank agent // <", x$name, ">")
     
   } else {
     
     print_stmt <-
       paste0(
-        "pointblank agent // <", x$validation_name, ">", "\n", "\n",
-        "tables of focus: ",
-        paste(tables_of_focus, collapse = ", "),
-        ".", "\n",
+        "pointblank agent // <", x$name, ">", "\n", "\n",
         "number of validation steps: ", number_of_validation_steps(x), "\n"
       )
     
-    if (did_agent_interrogate(x)) {
+    if (has_agent_intel(x)) {
       
       passing_steps <-
         length(which(x$validation_set$all_passed == TRUE))
@@ -69,10 +52,12 @@ print.ptblank_agent <- function(x, ...) {
           " failing validation",
           ifelse(failing_steps == 1, "", "s"),
           "   ",
-          "more info: `get_interrogation_summary()`"
+          "more info: `get_agent_report()`\n"
         )
     }
   }
   
   cat(print_stmt)
+  
+  # nocov end 
 }
