@@ -1,21 +1,27 @@
 utils::globalVariables(
   c(
     ".",
+    "__pb_index__",
     "action",
+    "assertion_type",
     "brief",
-    "component_name",
-    "db_type",
+    "column",
+    "extract",
+    "f_pass",
     "f_passed",
     "n",
+    "N",
     "notify",
     "pb_is_good_",
     "pb_step_",
-    "set",
-    "sql",
-    "tbl_name",
+    "pb_sum",
+    "preconds",
+    "S",
     "tbl_name_type",
     "tbl_name_type_n",
+    "type",
     "value",
+    "W",
     "warn",
     "x"
   )
